==> chrome-devtools-kotlin-0.2.0-sources.jar: org/hildan/chrome/devtools/domains/security/events/SecurityEvents.kt <==
package org.hildan.chrome.devtools.domains.security.events

import kotlin.Boolean
import kotlin.Deprecated
import kotlin.Int
import kotlin.String
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.security.InsecureContentStatus
import org.hildan.chrome.devtools.domains.security.SecurityState
import org.hildan.chrome.devtools.domains.security.SecurityStateExplanation
import org.hildan.chrome.devtools.domains.security.VisibleSecurityState

@Serializable
public sealed class SecurityEvent {
  @Serializable
  public data class CertificateErrorEvent(
    /**
     * The ID of the event.
     */
    public val eventId: Int,
    /**
     * The type of the error.
     */
    public val errorType: String,
    /**
     * The url that was requested.
     */
    public val requestURL: String
  ) : SecurityEvent()

  @Serializable
  public data class VisibleSecurityStateChangedEvent(
    /**
     * Security state information about the page.
     */
    public val visibleSecurityState: VisibleSecurityState
  ) : SecurityEvent()

  @Serializable
  public data class SecurityStateChangedEvent(
    /**
     * Security state.
     */
    public val securityState: SecurityState,
    /**
     * True if the page was loaded over cryptographic transport such as HTTPS.
     */
    @Deprecated(message = "Deprecated in the Chrome DevTools protocol")
    public val schemeIsCryptographic: Boolean,
    /**
     * List of explanations for the security state. If the overall security state is `insecure` or
     * `warning`, at least one corresponding explanation should be included.
     */
    public val explanations: List<SecurityStateExplanation>,
    /**
     * Information about insecure content on the page.
     */
    @Deprecated(message = "Deprecated in the Chrome DevTools protocol")
    public val insecureContentStatus: InsecureContentStatus,
    /**
     * Overrides user-visible description of the state.
     */
    public val summary: String? = null
  ) : SecurityEvent()
}

==> chrome-devtools-kotlin-0.8.0-sources.jar: org/hildan/chrome/devtools/domains/security/events/SecurityEvents.kt <==
package org.hildan.chrome.devtools.domains.security.events

import kotlin.Boolean
import kotlin.Deprecated
import kotlin.Int
import kotlin.String
import kotlin.collections.List
import kotlinx.serialization.Serializable
import org.hildan.chrome.devtools.domains.security.InsecureContentStatus
import org.hildan.chrome.devtools.domains.security.SecurityState
import org.hildan.chrome.devtools.domains.security.SecurityStateExplanation
import org.hildan.chrome.devtools.domains.security.VisibleSecurityState
import org.hildan.chrome.devtools.protocol.ExperimentalChromeApi

@Serializable
public sealed class SecurityEvent {
  /**
   * There is a certificate error. If overriding certificate errors is enabled, then it should be
   * handled with the `handleCertificateError` command. Note: this event does not fire if the
   * certificate error has been allowed internally. Only one client per target should override
   * certificate errors at the same time.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Security/#event-certificateError)
   */
  @Deprecated(message = "Deprecated in the Chrome DevTools protocol")
  @Serializable
  public data class CertificateErrorEvent(
    /**
     * The ID of the event.
     */
    public val eventId: Int,
    /**
     * The type of the error.
     */
    public val errorType: String,
    /**
     * The url that was requested.
     */
    public val requestURL: String
  ) : SecurityEvent()

  /**
   * The security state of the page changed.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Security/#event-visibleSecurityStateChanged)
   */
  @ExperimentalChromeApi
  @Serializable
  public data class VisibleSecurityStateChangedEvent(
    /**
     * Security state information about the page.
     */
    public val visibleSecurityState: VisibleSecurityState
  ) : SecurityEvent()

  /**
   * The security state of the page changed.
   *
   * [Official doc](https://chromedevtools.github.io/devtools-protocol/tot/Security/#event-securityStateChanged)
   */
  @Serializable
  public data class SecurityStateChangedEvent(
    /**
     * Security state.
     */
    public val securityState: SecurityState,
    /**
     * True if the page was loaded over cryptographic transport such as HTTPS.
     */
    @Deprecated(message = "Deprecated in the Chrome DevTools protocol")
    public val schemeIsCryptographic: Boolean,
    /**
     * List of explanations for the security state. If the overall security state is `insecure` or
     * `warning`, at least one corresponding explanation should be included.
     */
    public val explanations: List<SecurityStateExplanation>,
    /**
     * Information about insecure content on the page.
     */
    @Deprecated(message = "Deprecated in the Chrome DevTools protocol")
    public val insecureContentStatus: InsecureContentStatus,
    /**
     * Overrides user-visible description of the state.
     */
    public val summary: String? = null
  ) : SecurityEvent()
}
